==> zzyj-financeintegration-impl-3.0.0-20251124.033822-132-sources.jar: com/ejianc/business/financeintegration/PMSalary/controller/api/PMSalarySystemApiController.java <==
package com.ejianc.business.financeintegration.PMSalary.controller.api;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.financeintegration.PMPayApply.service.IPMSalaryPayApplyService;
import com.ejianc.business.financeintegration.PMPayApply.util.RedisUtil;
import com.ejianc.business.financeintegration.PMPayApply.vo.PMSalaryPayApplyVO;
import com.ejianc.business.financeintegration.PMSalary.bean.PMGzDetailEntity;
import com.ejianc.business.financeintegration.PMSalary.bean.PMGzEntity;
import com.ejianc.business.financeintegration.PMSalary.bean.PMSbgjjgsEntity;
import com.ejianc.business.financeintegration.PMSalary.service.IPMSalarySystemDetailService;
import com.ejianc.business.financeintegration.PMSalary.service.IPMSalarySystemSBService;
import com.ejianc.business.financeintegration.PMSalary.service.IPMSalarySystemService;
import com.ejianc.business.financeintegration.PMSalary.vo.PMGzDetailVO;
import com.ejianc.business.financeintegration.PMSalary.vo.PMGzVO;
import com.ejianc.business.financeintegration.PMSalary.vo.PMSbgjjgsVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.cache.utils.RedisTool;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import redis.clients.jedis.Jedis;
import redis.clients.jedis.JedisPool;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 薪资系统
 *
 * @author generator
 */
@RestController
@RequestMapping("/api/PMSalarySystemApply/")
public class PMSalarySystemApiController {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IPMSalarySystemService pmSalaryPayService;
    @Autowired
    private IPMSalarySystemSBService sbgjjService;
    @Autowired
    private IPMSalarySystemDetailService systemDetailService;
    @Autowired
    private JedisPool jedisPool;

    private final String OPERATE = "PM_SALARY_SYSTEM_SAVE";

    private long retryInterval = 60000;

    private final int maxRetryTime = 10;

    // 工人工资单支付申请生效
    @PostMapping(value = "salaryTakeEffect")
    public CommonResponse<PMGzVO> salaryTakeEffect(@RequestBody List<PMGzVO> vo) {
        Jedis jedis = null;
        String key = null;
        int retryTime = 0;
        boolean lock = false;
        if (CollectionUtils.isNotEmpty(vo)) {

                try {
                    key = getLockKey(vo.get(0).getId());
                    jedis = jedisPool.getResource();
                    while (!lock && retryTime <= maxRetryTime) {
                        if (retryTime > 0) {
                            logger.info("键-{}第{}次尝试获取redis锁, 第{}毫秒后开始尝试", key, retryTime, retryTime * retryInterval);
                            Thread.sleep(retryTime * retryInterval);
                        }
                        retryTime++;
                        lock = getLock(key, jedis);
                    }

                    if(!lock && retryTime > maxRetryTime) {
                        logger.info("键-{}第{}次尝试获取redis锁失败，已达到最大尝试次数，本次核销失败！", key, retryTime);
                        return CommonResponse.error("薪资结果处理失败!");
                    }

                    for (PMGzVO salaryPayApplyVO : vo) {
                        CommonResponse<PMGzVO> pmGzVOCommonResponse = pmSalaryPayService.salaryTakeEffect(salaryPayApplyVO);
                        logger.info("本次数据解析完成!!!!!!!!!!!!!!!!!!，{}",JSONObject.toJSONString(pmGzVOCommonResponse));
                        if (pmGzVOCommonResponse.getCode() != 0){
                            logger.info("推送财务中间库失败!!!!!!!!!!!!!!!!!!，{}",salaryPayApplyVO.getPmBillId());
                            return pmGzVOCommonResponse;
                        }
                    }
                    logger.info("推送财务中间库成功!!!!!!!!!!!!!!!!!!");

//                    PMGzVO pmGzVO = new PMGzVO();
                    return CommonResponse.success("推送财务中间库成功", null);
                } catch (Exception e) {
                    logger.error("付款结果处理失败！pmSalaryPayApplyVO-{}", JSONObject.toJSONString(vo.get(0)), e);
                    return CommonResponse.error("付款结果处理失败!");
                } finally {
                    //释放单据锁
                    RedisUtil.unLock(jedis, false, key, OPERATE);
                    logger.info("redisKey-{}进行Redis锁释放", key);
            }
        }else {
            return CommonResponse.error("付款数据传输失败!");
        }
    }


    // 工资支付申请弃审/关闭
    @PostMapping(value = "salaryAbandonOrClose")
    public CommonResponse<PMGzVO> salaryAbandonOrClose(@RequestBody PMGzVO salaryPayApplyVO){
        Jedis jedis = null;
        String key = null;
        int retryTime = 0;
        boolean lock = false;
        try {
            key = getLockKey(salaryPayApplyVO.getId());
            jedis = jedisPool.getResource();
            while(!lock && retryTime <= maxRetryTime) {
                if(retryTime >0 ){
                    logger.info("键-{}第{}次尝试获取redis锁, 第{}毫秒后开始尝试", key, retryTime, retryTime * retryInterval);
                    Thread.sleep(retryTime * retryInterval);
                }
                retryTime++;
                lock = getLock(key, jedis);
            }

            return pmSalaryPayService.salaryAbandonOrClose(salaryPayApplyVO);
        } catch (Exception e) {
            logger.error("付款结果处理失败！pmSalaryPayApplyVO-{}", JSONObject.toJSONString(salaryPayApplyVO));
            return CommonResponse.error("付款结果处理失败!");
        } finally {
            //释放单据锁
            RedisUtil.unLock(jedis, false, key, OPERATE);
            logger.info("redisKey-{}进行Redis锁释放", key);
        }
    }

    // 工资支付申请定时任务
    @PostMapping(value = "salaryTimingTask")
    public CommonResponse<String> salaryTimingTask(){
        return pmSalaryPayService.salaryPayApplyTimingTask();
    }



    private String getLockKey(String id) {
        logger.info("处理薪资系统数据-{}前加锁", id);
        // 根据数据维度获取锁，维度：工人工资支付申请单id
        String redisKey = "PM::"+id;
        logger.info("对保存操作添加Redis锁，redisKey-{}", redisKey);
        return redisKey;
    }

    private Boolean getLock(String key, Jedis jedis) {
        logger.info("从jedisPool获取jedis对象，jedis对象-{}", jedis);
        try {
            // 在数据维度层面进行加锁
            return RedisTool.tryLock(jedis, key, OPERATE, 600);
        } catch (Exception e) {
            logger.info("根据键-{}获取reids锁异常", key, e);
            return false;
        }
    }



    // 社保公积金生效
    @PostMapping(value = "sbTakeEffect")
    CommonResponse<PMSbgjjgsVO> sbTakeEffect(@RequestBody List<PMSbgjjgsVO> vo){
        Jedis jedis = null;
        String key = null;
        int retryTime = 0;
        boolean lock = false;
        if (CollectionUtils.isNotEmpty(vo)) {

            try {
                key = getLockKey(vo.get(0).getId());
                jedis = jedisPool.getResource();
                while (!lock && retryTime <= maxRetryTime) {
                    if (retryTime > 0) {
                        logger.info("键-{}第{}次尝试获取redis锁, 第{}毫秒后开始尝试", key, retryTime, retryTime * retryInterval);
                        Thread.sleep(retryTime * retryInterval);
                    }
                    retryTime++;
                    lock = getLock(key, jedis);
                }

                if(!lock && retryTime > maxRetryTime) {
                    logger.info("键-{}第{}次尝试获取redis锁失败，已达到最大尝试次数，本次核销失败！", key, retryTime);
                    return CommonResponse.error("社保结果处理失败!");
                }

                for (PMSbgjjgsVO salaryPayApplyVO : vo) {
                    CommonResponse<PMSbgjjgsVO> pmGzVOCommonResponse = pmSalaryPayService.sbTakeEffect(salaryPayApplyVO);
                    if (pmGzVOCommonResponse.getCode() != 0){
                        return pmGzVOCommonResponse;
                    }
                }
                PMSbgjjgsVO pmSbgjjgsVO = new PMSbgjjgsVO();
                return CommonResponse.success("推送财务中间库成功",pmSbgjjgsVO);
            } catch (Exception e) {
                logger.error("付款结果处理失败！pmSalaryPayApplyVO-{}", JSONObject.toJSONString(vo.get(0)), e);
                return CommonResponse.error("付款结果处理失败!");
            } finally {
                //释放单据锁
                RedisUtil.unLock(jedis, false, key, OPERATE);
                logger.info("redisKey-{}进行Redis锁释放", key);
            }
        }else {
            return CommonResponse.success("付款数据传输为空，没有社保数据!");
        }
    }


    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JSONObject> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("acName");
        fuzzyFields.add("acCode");
        Page<PMSbgjjgsEntity> page = new Page<>(param.getPageIndex(), param.getPageSize());
        QueryWrapper wrapper = BaseServiceImpl.changeToQueryWrapper(param);

        List<PMSbgjjgsVO> pageList = sbgjjService.queryPageList(page, wrapper);
        IPage<PMSbgjjgsVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        //pageData.setRecords(pageList);
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("records", pageList);
        jsonObject.put("total", pageData.getTotal());
        jsonObject.put("current", pageData.getCurrent());
        jsonObject.put("size", pageData.getSize());
        jsonObject.put("pages", pageData.getPages());
        return CommonResponse.success("查询列表数据成功！",jsonObject);
    }


    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryGZList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<JSONObject> queryGZList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("acName");
        fuzzyFields.add("acCode");
        Page<PMGzEntity> page = new Page<>(param.getPageIndex(), param.getPageSize());
        QueryWrapper wrapper = BaseServiceImpl.changeToQueryWrapper(param);

        List<PMGzDetailVO> pageList = sbgjjService.queryGzPageList(page, wrapper);
        IPage<PMGzDetailVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
//        pageData.setRecords(pageList);

        JSONObject jsonObject = new JSONObject();
        jsonObject.put("records", pageList);
        jsonObject.put("total", pageData.getTotal());
        jsonObject.put("current", pageData.getCurrent());
        jsonObject.put("size", pageData.getSize());
        jsonObject.put("pages", pageData.getPages());

        return CommonResponse.success("查询列表数据成功！",jsonObject);
    }


    // 查询工资明细
    @PostMapping(value = "/api/PMSalarySystemApply/querySalaryDetailList")
    CommonResponse<JSONObject> querySalaryDetailList(@RequestBody QueryParam param){
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("id");
        fuzzyFields.add("name");
        fuzzyFields.add("idCard");
        fuzzyFields.add("bankName");
        fuzzyFields.add("bankCount");
        fuzzyFields.add("bankAddress");
        fuzzyFields.add("pmBillId");
        Page<PMGzEntity> page = new Page<>(param.getPageIndex(), param.getPageSize());

        List<PMGzDetailEntity> pageList = systemDetailService.queryList(param);
        IPage<PMGzDetailVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());

        JSONObject jsonObject = new JSONObject();
        jsonObject.put("records", pageList);
        jsonObject.put("total", pageData.getTotal());
        jsonObject.put("current", pageData.getCurrent());
        jsonObject.put("size", pageData.getSize());
        jsonObject.put("pages", pageData.getPages());

        return CommonResponse.success("查询工资明细列表数据成功！",jsonObject);
    }


    @Autowired
    private IPMSalarySystemSBService salarySystemSBService;
  /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refPMGzDetailData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<JSONObject> refPMGzDetailData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                     String condition,
                                                                     String searchObject,
                                                                     String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);

        Map<String, Object> conditionMap = JSONObject.parseObject(condition, Map.class);
        if (null != conditionMap.get("acSetCode")) {
            String acSetCode = conditionMap.get("acSetCode").toString();
            param.getParams().put("acCode", new Parameter(QueryParam.EQ, acSetCode));
        }

        if (null != conditionMap.get("month")) {
            String month = conditionMap.get("month").toString();
            param.getParams().put("yearMonth", new Parameter(QueryParam.EQ, month));
            param.getParams().put("sub_pm_bill_id", new Parameter(QueryParam.LIKE, "-"));
        }

//        if (null != conditionMap.get("companyId")) {
//            String companyId = conditionMap.get("companyId").toString();
//            param.getParams().put("pmBillId", new Parameter(QueryParam.LIKE, companyId));
//        }

        if (null != conditionMap.get("yybs")) {
            String yybs = conditionMap.get("yybs").toString();
//            param.getParams().put("acCode", new Parameter(QueryParam.EQ, yybs));
            param.getParams().put("yybs", new Parameter(QueryParam.EQ, yybs));
        }


        if (null != conditionMap.get("state")) {
            String state = conditionMap.get("state").toString();
            param.getParams().put("state", new Parameter(QueryParam.EQ, state));
        }

        Page<PMGzEntity> page = new Page<>(param.getPageIndex(), param.getPageSize());
        QueryWrapper wrapper = BaseServiceImpl.changeToQueryWrapper(param);

        List<PMGzDetailVO> pageList = sbgjjService.queryGzPageList(page, wrapper);
        IPage<PMGzDetailVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
//        pageData.setRecords(pageList);

        JSONObject jsonObject = new JSONObject();
        jsonObject.put("records", pageList);
        jsonObject.put("total", pageData.getTotal());
        jsonObject.put("current", pageData.getCurrent());
        jsonObject.put("size", pageData.getSize());
        jsonObject.put("pages", pageData.getPages());

        return CommonResponse.success("查询参照数据成功！",jsonObject);
    }


    // 根据id修改工资明细子表的支付状态和修改时间
    @PostMapping(value = "changeSalaryDetailState")
    public CommonResponse<JSONObject> changeSalaryDetailState(@RequestBody List<String> vo) {
        Jedis jedis = null;
        String key = null;
        int retryTime = 0;
        boolean lock = false;
        if (CollectionUtils.isNotEmpty(vo)) {

            try {
                key = getLockKey(vo.get(0));
                jedis = jedisPool.getResource();
                while (!lock && retryTime <= maxRetryTime) {
                    if (retryTime > 0) {
                        logger.info("键-{}第{}次尝试获取redis锁, 第{}毫秒后开始尝试", key, retryTime, retryTime * retryInterval);
                        Thread.sleep(retryTime * retryInterval);
                    }
                    retryTime++;
                    lock = getLock(key, jedis);
                }
                CommonResponse<JSONObject> pmGzVOCommonResponse = pmSalaryPayService.changeSalaryDetailState(vo);
                if (pmGzVOCommonResponse.getCode() != 0){
                    return pmGzVOCommonResponse;
                }

                return CommonResponse.success("修改财务中间库支付状态成功");
            } catch (Exception e) {
                logger.error("修改财务中间库支付状态！pmSalaryPayApplyVO-{}", JSONObject.toJSONString(vo.get(0)), e);
                return CommonResponse.error("修改财务中间库支付状态失败!");
            } finally {
                //释放单据锁
                RedisUtil.unLock(jedis, false, key, OPERATE);
                logger.info("redisKey-{}进行Redis锁释放", key);
            }
        }else {
            return CommonResponse.error("付款数据传输失败!");
        }
    }

}

==> zzyj-financeintegration-impl-3.0.0-20251208.062355-133-sources.jar: com/ejianc/business/financeintegration/PMSalary/controller/api/PMSalarySystemApiController.java <==
package com.ejianc.business.financeintegration.PMSalary.controller.api;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.financeintegration.PMPayApply.service.IPMSalaryPayApplyService;
import com.ejianc.business.financeintegration.PMPayApply.util.RedisUtil;
import com.ejianc.business.financeintegration.PMPayApply.vo.PMSalaryPayApplyVO;
import com.ejianc.business.financeintegration.PMSalary.service.IPMSalarySystemService;
import com.ejianc.business.financeintegration.PMSalary.vo.PMGzVO;
import com.ejianc.business.financeintegration.PMSalary.vo.PMSbgjjgsVO;
import com.ejianc.framework.cache.utils.RedisTool;
import com.ejianc.framework.core.response.CommonResponse;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import redis.clients.jedis.Jedis;
import redis.clients.jedis.JedisPool;

import java.util.List;

/**
 * 薪资系统
 *
 * @author generator
 */
@RestController
@RequestMapping("/api/PMSalarySystemApply/")
public class PMSalarySystemApiController {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IPMSalarySystemService pmSalaryPayService;

    @Autowired
    private JedisPool jedisPool;

    private final String OPERATE = "PM_SALARY_SYSTEM_SAVE";

    private long retryInterval = 60000;

    private final int maxRetryTime = 10;

    // 工人工资单支付申请生效
    @PostMapping(value = "salaryTakeEffect")
    public CommonResponse<PMGzVO> salaryTakeEffect(@RequestBody List<PMGzVO> vo) {
        Jedis jedis = null;
        String key = null;
        int retryTime = 0;
        boolean lock = false;
        if (CollectionUtils.isNotEmpty(vo)) {

                try {
                    key = getLockKey(vo.get(0).getId());
                    jedis = jedisPool.getResource();
                    while (!lock && retryTime <= maxRetryTime) {
                        if (retryTime > 0) {
                            logger.info("键-{}第{}次尝试获取redis锁, 第{}毫秒后开始尝试", key, retryTime, retryTime * retryInterval);
                            Thread.sleep(retryTime * retryInterval);
                        }
                        retryTime++;
                        lock = getLock(key, jedis);
                    }
                    for (PMGzVO salaryPayApplyVO : vo) {
                        CommonResponse<PMGzVO> pmGzVOCommonResponse = pmSalaryPayService.salaryTakeEffect(salaryPayApplyVO);
                        if (pmGzVOCommonResponse.getCode() != 0){
                            return pmGzVOCommonResponse;
                        }
                    }
                    return CommonResponse.success("推送财务中间库成功");
                } catch (Exception e) {
                    logger.error("付款结果处理失败！pmSalaryPayApplyVO-{}", JSONObject.toJSONString(vo.get(0)), e);
                    return CommonResponse.error("付款结果处理失败!");
                } finally {
                    //释放单据锁
                    RedisUtil.unLock(jedis, false, key, OPERATE);
                    logger.info("redisKey-{}进行Redis锁释放", key);
            }
        }else {
            return CommonResponse.error("付款数据传输失败!");
        }
    }


    // 工资支付申请弃审/关闭
    @PostMapping(value = "salaryAbandonOrClose")
    public CommonResponse<PMGzVO> salaryAbandonOrClose(@RequestBody PMGzVO salaryPayApplyVO){
        Jedis jedis = null;
        String key = null;
        int retryTime = 0;
        boolean lock = false;
        try {
            key = getLockKey(salaryPayApplyVO.getId());
            jedis = jedisPool.getResource();
            while(!lock && retryTime <= maxRetryTime) {
                if(retryTime >0 ){
                    logger.info("键-{}第{}次尝试获取redis锁, 第{}毫秒后开始尝试", key, retryTime, retryTime * retryInterval);
                    Thread.sleep(retryTime * retryInterval);
                }
                retryTime++;
                lock = getLock(key, jedis);
            }

            return pmSalaryPayService.salaryAbandonOrClose(salaryPayApplyVO);
        } catch (Exception e) {
            logger.error("付款结果处理失败！pmSalaryPayApplyVO-{}", JSONObject.toJSONString(salaryPayApplyVO));
            return CommonResponse.error("付款结果处理失败!");
        } finally {
            //释放单据锁
            RedisUtil.unLock(jedis, false, key, OPERATE);
            logger.info("redisKey-{}进行Redis锁释放", key);
        }
    }

    // 工资支付申请定时任务
    @PostMapping(value = "salaryTimingTask")
    public CommonResponse<String> salaryTimingTask(){
        return pmSalaryPayService.salaryPayApplyTimingTask();
    }



    private String getLockKey(String id) {
        logger.info("处理薪资系统数据-{}前加锁", id);
        // 根据数据维度获取锁，维度：工人工资支付申请单id
        String redisKey = "PM::"+id;
        logger.info("对保存操作添加Redis锁，redisKey-{}", redisKey);
        return redisKey;
    }

    private Boolean getLock(String key, Jedis jedis) {
        logger.info("从jedisPool获取jedis对象，jedis对象-{}", jedis);
        try {
            // 在数据维度层面进行加锁
            return RedisTool.tryLock(jedis, key, OPERATE, 600);
        } catch (Exception e) {
            logger.info("根据键-{}获取reids锁异常", key, e);
            return false;
        }
    }



    // 社保公积金生效
    @PostMapping(value = "sbTakeEffect")
    CommonResponse<PMSbgjjgsVO> sbTakeEffect(@RequestBody List<PMSbgjjgsVO> vo){
        Jedis jedis = null;
        String key = null;
        int retryTime = 0;
        boolean lock = false;
        if (CollectionUtils.isNotEmpty(vo)) {

            try {
                key = getLockKey(vo.get(0).getId());
                jedis = jedisPool.getResource();
                while (!lock && retryTime <= maxRetryTime) {
                    if (retryTime > 0) {
                        logger.info("键-{}第{}次尝试获取redis锁, 第{}毫秒后开始尝试", key, retryTime, retryTime * retryInterval);
                        Thread.sleep(retryTime * retryInterval);
                    }
                    retryTime++;
                    lock = getLock(key, jedis);
                }
                for (PMSbgjjgsVO salaryPayApplyVO : vo) {
                    CommonResponse<PMSbgjjgsVO> pmGzVOCommonResponse = pmSalaryPayService.sbTakeEffect(salaryPayApplyVO);
                    if (pmGzVOCommonResponse.getCode() != 0){
                        return pmGzVOCommonResponse;
                    }
                }
                return CommonResponse.success("推送财务中间库成功");
            } catch (Exception e) {
                logger.error("付款结果处理失败！pmSalaryPayApplyVO-{}", JSONObject.toJSONString(vo.get(0)), e);
                return CommonResponse.error("付款结果处理失败!");
            } finally {
                //释放单据锁
                RedisUtil.unLock(jedis, false, key, OPERATE);
                logger.info("redisKey-{}进行Redis锁释放", key);
            }
        }else {
            return CommonResponse.error("付款数据传输失败!");
        }
    }

}
